@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="1.1" language="en_US">
+<!DOCTYPE TS><TS version="2.0" language="en_US" sourcelanguage="">
 <context encoding="UTF-8">
     <name>Aide</name>
     <message>
@@ -672,7 +672,7 @@ p, li { white-space: pre-wrap; }
         <translation>Disk size</translation>
     </message>
     <message>
-        <location filename="../Ui_mainWindow.py" line="160"/>
+        <location filename="../Ui_diskFull.py" line="57"/>
         <source>...</source>
         <translation>...</translation>
     </message>
@@ -762,12 +762,12 @@ p, li { white-space: pre-wrap; }
         <translation>Preferences</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="165"/>
+        <location filename="../Ui_mainWindow.py" line="147"/>
         <source>Refaire à nouveau</source>
         <translation>Redo last command</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="166"/>
+        <location filename="../Ui_mainWindow.py" line="148"/>
         <source>Refaire à nouveau la dernière opération réussie, avec les baladeurs connectés plus récemment</source>
         <translation>Redo the last successful command, with newly connected medias</translation>
     </message>
@@ -805,47 +805,47 @@ p, li { white-space: pre-wrap; }
 <context>
     <name>checkBoxDialog</name>
     <message encoding="UTF-8">
-        <location filename="../checkBoxDialog.ui" line="14"/>
+        <location filename="../Ui_checkBoxDialog.py" line="55"/>
         <source>Gestion des cases à cocher</source>
         <translation>Checkbox manager</translation>
     </message>
     <message>
-        <location filename="../checkBoxDialog.ui" line="27"/>
+        <location filename="../Ui_checkBoxDialog.py" line="57"/>
         <source>Cocher tous les baladeurs</source>
         <translation>Check all the medias</translation>
     </message>
     <message>
-        <location filename="../checkBoxDialog.ui" line="30"/>
+        <location filename="../Ui_checkBoxDialog.py" line="58"/>
         <source>Tout cocher</source>
         <translation>Check all</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../checkBoxDialog.ui" line="44"/>
+        <location filename="../Ui_checkBoxDialog.py" line="60"/>
         <source>Inverser le choix de baladeurs&lt;br&gt;Les baladeurs cochés seront décochés, et inversement</source>
         <translation>Toggle checks&lt;br&gt;Selected medias will be unselected, and vice versa</translation>
     </message>
     <message>
-        <location filename="../checkBoxDialog.ui" line="47"/>
+        <location filename="../Ui_checkBoxDialog.py" line="61"/>
         <source>Inverser le choix</source>
         <translation>Toggle the checks</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../checkBoxDialog.ui" line="61"/>
+        <location filename="../Ui_checkBoxDialog.py" line="63"/>
         <source>Désélectionner les baladeurs</source>
         <translation>Unselect the medias</translation>
     </message>
     <message>
-        <location filename="../checkBoxDialog.ui" line="64"/>
+        <location filename="../Ui_checkBoxDialog.py" line="64"/>
         <source>Ne rien cocher</source>
         <translation>Check none</translation>
     </message>
     <message>
-        <location filename="../checkBoxDialog.ui" line="78"/>
+        <location filename="../Ui_checkBoxDialog.py" line="66"/>
         <source>Ne rien faire</source>
         <translation>Do nothing</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../checkBoxDialog.ui" line="81"/>
+        <location filename="../Ui_checkBoxDialog.py" line="67"/>
         <source>Échappement</source>
         <translation>Escape</translation>
     </message>
