@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="1.1">
+<!DOCTYPE TS><TS version="2.0">
 <context>
     <name>Aide</name>
     <message>
@@ -457,7 +457,7 @@ p, li { white-space: pre-wrap; }
         <translation>Taille du disque</translation>
     </message>
     <message>
-        <location filename="../Ui_mainWindow.py" line="160"/>
+        <location filename="../Ui_diskFull.py" line="57"/>
         <source>...</source>
         <translation type="unfinished"></translation>
     </message>
@@ -522,12 +522,12 @@ p, li { white-space: pre-wrap; }
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="165"/>
+        <location filename="../Ui_mainWindow.py" line="147"/>
         <source>Refaire à nouveau</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="166"/>
+        <location filename="../Ui_mainWindow.py" line="148"/>
         <source>Refaire à nouveau la dernière opération réussie, avec les baladeurs connectés plus récemment</source>
         <translation type="unfinished"></translation>
     </message>
@@ -565,47 +565,47 @@ p, li { white-space: pre-wrap; }
 <context>
     <name>checkBoxDialog</name>
     <message encoding="UTF-8">
-        <location filename="../checkBoxDialog.ui" line="14"/>
+        <location filename="../Ui_checkBoxDialog.py" line="55"/>
         <source>Gestion des cases à cocher</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../checkBoxDialog.ui" line="27"/>
+        <location filename="../Ui_checkBoxDialog.py" line="57"/>
         <source>Cocher tous les baladeurs</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../checkBoxDialog.ui" line="30"/>
+        <location filename="../Ui_checkBoxDialog.py" line="58"/>
         <source>Tout cocher</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../checkBoxDialog.ui" line="44"/>
+        <location filename="../Ui_checkBoxDialog.py" line="60"/>
         <source>Inverser le choix de baladeurs&lt;br&gt;Les baladeurs cochés seront décochés, et inversement</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../checkBoxDialog.ui" line="47"/>
+        <location filename="../Ui_checkBoxDialog.py" line="61"/>
         <source>Inverser le choix</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../checkBoxDialog.ui" line="61"/>
+        <location filename="../Ui_checkBoxDialog.py" line="63"/>
         <source>Désélectionner les baladeurs</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../checkBoxDialog.ui" line="64"/>
+        <location filename="../Ui_checkBoxDialog.py" line="64"/>
         <source>Ne rien cocher</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../checkBoxDialog.ui" line="78"/>
+        <location filename="../Ui_checkBoxDialog.py" line="66"/>
         <source>Ne rien faire</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../checkBoxDialog.ui" line="81"/>
+        <location filename="../Ui_checkBoxDialog.py" line="67"/>
         <source>Échappement</source>
         <translation type="unfinished"></translation>
     </message>
